#[non_exhaustive]pub enum Error {
InvalidKeyLength,
InvalidNonceLength,
InvalidTagLength,
InvalidLength,
AadAfterPayload,
Hardware,
}Expand description
Symmetric crypto error.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidKeyLength
The key length is not supported by the hardware.
InvalidNonceLength
The nonce or IV length is not valid for the cipher mode.
InvalidTagLength
The tag length is not valid for the cipher mode.
InvalidLength
The data length is not valid.
Returned when:
- the input and output lengths differ,
- a chunk that is not the last one is not a multiple of the block length, for modes that require it,
- the amount of data does not match the lengths given to
AesCcm::new.
AadAfterPayload
Additional authenticated data was supplied after payload data.
Hardware
The hardware reported an error.