pub struct AesCbc { /* private fields */ }Expand description
AES in CBC (cipher block chaining) mode.
Data must be a multiple of the block length.
The IV must be unpredictable and unique for every message.
Implementations